@@ -171,8 +171,6 @@
      (destructuring-bind (sym &optional normalizep) param
        (setf (symbol-value sym)
              (if normalizep (normalize-flags sbcl-home val) val))))
-    (unless (featurep :sb-linkable-runtime)
-      (setf *linkkit-start* nil *linkkit-end* nil))
     (setf *ld* *cc* ;; !
           *ld-dll-flags* (list* #+darwin "-dynamiclib" #-darwin "-shared"
                                 *cc-flags*))))
@@ -273,7 +271,6 @@ is bound to a temporary file name, then atomically renaming that temporary file
   #+mkcl (compiler::build-program
           output-file :lisp-object-files (mapcar 'program-argument inputs)
           :on-missing-lisp-object-initializer nil)
-  #+(and sbcl (not sb-linkable-runtime)) (error "Your SBCL doesn't support :SB-LINKABLE-RUNTIME")
   #-(or ecl mkcl)
   (link-executable output-file `(,@*linkkit-start* ,@inputs ,@*linkkit-end*)))
 
